/// <reference types="react" />
import { ButtonProps } from '@mui/material';
import { ThemeProviderProps as ThemeProviderProps$1 } from '@emotion/react';

declare type Button$1 = {
    /**
     * A className can be passed to use custom styles
     */
    className?: string;
    /**
     * Is this the principal call to action on the page?
     */
    primary?: boolean;
    /**
     * The button color, comes from the Theme, can be overridden using the background color prop
     */
    color?: ButtonProps['color'];
    /**
     * The button text color
     */
    textColor?: string;
    /**
     * What background color to use
     */
    backgroundColor?: string;
    /**
     * What border color to use
     */
    borderColor?: string;
    /**
     * How large should the button be?
     */
    size?: ButtonProps['size'];
    /**
     * The button tag type
     */
    type?: ButtonProps['type'];
    /**
     * The button variant
     */
    variant?: ButtonProps['variant'];
    /**
     * Button contents
     */
    label?: string;
    /**
     * If the button should take the entire space
     */
    fullWidth?: ButtonProps['fullWidth'];
    /**
     * If the button text should be uppercase
     * default is true
     */
    uppercase?: boolean;
    /**
     * If the button should be rounded
     */
    rounded?: boolean;
    /**
     * Optional click handler
     */
    onClick?: () => void;
    href?: string;
    /**
     * The button rel values. possible to add more values with comma selected
     */
    relValues?: string;
    /**
     * The button target value. Will only be applied to <a> element
     */
    target?: string;
};

declare const Button: React.FC<Button$1>;

declare type ThemeProviderProps = ThemeProviderProps$1;
declare const ThemeProvider: React.FC<ThemeProviderProps>;

export { Button, ThemeProvider };
